#!/usr/bin/env ruby

require 'optparse'
require 'tempfile'

options = {}

opt_parser = OptionParser.new do |opt|
	opt.banner = "Usage: application_localised_xib_generation.rb [OPTIONS]"
	opt.separator  ""
	opt.separator  "Options"
	
	opt.on("-s", "--sourceResourcesPath [SOURCE_RESOURCE_PATH]", "the path to the source resources path") do |source_resources_path|
    	options[:sourceResourcesPath] = source_resources_path
	end
	
	opt.on("-a", "--applicationResourcesPath [APP_RESOURCE_PATH]", "the path to the application resources path") do |application_resources_path|
    	options[:applicationResourcesPath] = application_resources_path
	end
	
	opt.on("-d", "--developmentRegion [DEV_REGION]", "the development region") do |development_region|
    	options[:developmentRegion] = development_region
	end
end

opt_parser.parse!

source_resources_path = options[:sourceResourcesPath]
application_resources_path = options[:applicationResourcesPath]
development_region = options[:developmentRegion]

if !source_resources_path || !application_resources_path || !development_region
	puts opt_parser
	exit -1
end

def finish
	print "============  XIB STRINGS EXTRACTION SUCCESS   ============\n"
end

def fail(reason = nil, severity = :warning)
	print "\n"
	print "============  XIB STRINGS EXTRACTION FAILURE   ============\n"
	unless reason.nil?
		print "error: #{reason}\n"
	end
	print "\n"
	
	if severity == :fatal
		exit 1
	end
	
	def finish
		fail nil, :fatal
	end
end

development_resources_location = File.join(source_resources_path, development_region) + '.lproj'

developmentXIBs = []
Dir.foreach(development_resources_location) do |item|
	xibLocation = File.join(development_resources_location, item)
	next unless File.extname(xibLocation) == '.xib'
	developmentXIBs << xibLocation
end

localisedProjects = []
Dir.foreach(source_resources_path) do |item|
	resourceLocation = File.join(source_resources_path, item)
	next unless File.extname(resourceLocation) == '.lproj'
	localisedProjects << resourceLocation
end

ibtoolLocation = `xcrun -find ibtool`.strip

Dir.mktmpdir do |dir|
	localisedProjects.each do |localisedProject|
		developmentXIBs.each do |developmentXIB|
			localisedProjectFilename = File.basename(localisedProject)
			localisedRegionName = File.basename(localisedProject, File.extname(localisedProject))
			next if localisedRegionName == development_region
			
			filename = File.basename(developmentXIB, File.extname(developmentXIB))
			xibFilename = filename + '.xib'
			nibFilename = filename + '.nib'
			
			stringsLocation = File.join(localisedProject, filename + '.strings')
			
			temporaryExportLocation = File.join(dir, xibFilename)
			finalExportLocation = File.join(application_resources_path, localisedProjectFilename, nibFilename)
			
			if !File.file?(stringsLocation)
				fail("The strings file in #{localisedProjectFilename} at path #{stringsLocation} for #{xibFilename} is missing", :fatal)
			end
			
 			value = system(ibtoolLocation, "--strings-file", "#{stringsLocation}", "#{developmentXIB}", "--write", temporaryExportLocation)
 			
			if !value
				fail "couldn't create XIB for #{stringsLocation}"
			end
			
			value = system(ibtoolLocation, "--compile", "#{finalExportLocation}", "#{temporaryExportLocation}")
			
			if !value
				fail "couldn't compile XIB for #{stringsLocation}"
			end
			
			print "\n"
		end
	end
end

finish
